.. _spkg__cibuildwheel_local_c:

_cibuildwheel_local_c: Non-Python dependencies of packages for which we build platform wheels, side C
=====================================================================================================


Type
----

optional


Dependencies
------------

- :ref:`spkg_ccache`
- :ref:`spkg_ecl`
- :ref:`spkg_elliptic_curves`
- :ref:`spkg_fricas`
- :ref:`spkg_frobby`
- :ref:`spkg_gfan`
- :ref:`spkg_giac`
- :ref:`spkg_givaro`
- :ref:`spkg_gmp`
- :ref:`spkg_gsl`
- :ref:`spkg_kenzo`
- :ref:`spkg_libpng`
- :ref:`spkg_macaulay2`
- :ref:`spkg_maxima`
- :ref:`spkg_mpc`
- :ref:`spkg_mpfr`
- :ref:`spkg_msolve`
- :ref:`spkg_pip`
- :ref:`spkg_qepcad`
- :ref:`spkg_singular`
- :ref:`spkg_sirocco`
- :ref:`spkg_topcom`


Installation commands
---------------------

.. tab:: Sage distribution:

   .. CODE-BLOCK:: bash

       $ sage -i _cibuildwheel_local_c


